tlslite.utils.cipherfactory

Package tlslite :: Package utils :: Module cipherfactory |
[show private | hide private]
[frames | no frames]

## Module tlslite.utils.cipherfactory

Factory functions for symmetric cryptography.

Function Summary
`tlslite.utils.AES` | ``createAES`(key, IV, implList)` Create a new AES object.
`tlslite.utils.RC4` | ``createRC4`(key, IV, implList)` Create a new RC4 object.
`tlslite.utils.TripleDES` | ``createTripleDES`(key, IV, implList)` Create a new 3DES object.

Variable Summary
`bool` | `tripleDESPresent` = `True`

Function Details

### createAES(key, IV, implList=None) Create a new AES object. Parameters: `key` - A 16, 24, or 32 byte string. (type=str) `IV` - A 16 byte string (type=str) Returns: An AES object. (type=`tlslite.utils.AES`)

### createRC4(key, IV, implList=None) Create a new RC4 object. Parameters: `key` - A 16 to 32 byte string. (type=str) `IV` - Ignored, whatever it is. (type=object) Returns: An RC4 object. (type=`tlslite.utils.RC4`)

### createTripleDES(key, IV, implList=None) Create a new 3DES object. Parameters: `key` - A 24 byte string. (type=str) `IV` - An 8 byte string (type=str) Returns: A 3DES object. (type=`tlslite.utils.TripleDES`)

Variable Details

    ### tripleDESPresent Type: `bool` Value:
        True

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net